
#ifndef _C12_et594_
#define _C12_et594_

#ifdef __cplusplus
extern "C" {
#endif

extern void F1493_13779(EIF_REFERENCE, EIF_REFERENCE);
extern void EIF_Minit594(void);
extern char *(*R1696[])();

#ifdef __cplusplus
}
#endif

#endif
